## 0.1.0

- Initial release:
    - `tarot` command for performing Tarot readings
    - `oracle` command for integrating LLM interpretations and saved session management
    - Support for Ollama, Google Generative AI, and OpenRouter
    - Support for custom decks, spreads, and invocations
    - Configuration support for models and providers

